# coding: utf-8

"""
    Analysis

    Analyse content using Linked Data and Knowledge Graphs.

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wordlift_client.models.vector_search_query_request import VectorSearchQueryRequest

class TestVectorSearchQueryRequest(unittest.TestCase):
    """VectorSearchQueryRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> VectorSearchQueryRequest:
        """Test VectorSearchQueryRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `VectorSearchQueryRequest`
        """
        model = VectorSearchQueryRequest()
        if include_optional:
            return VectorSearchQueryRequest(
                filters = [
                    wordlift_client.models.filter.Filter(
                        key = '', 
                        operator = 'EQ', 
                        value = '', )
                    ],
                query_embedding = [
                    1.337
                    ],
                query_string = '',
                query_uri = '',
                query_url = '',
                similarity_top_k = 1
            )
        else:
            return VectorSearchQueryRequest(
        )
        """

    def testVectorSearchQueryRequest(self):
        """Test VectorSearchQueryRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    GraphQL support

    GraphQL endpoint to query Knowledge Graphs

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wordlift_client.api.include_excludes_api import IncludeExcludesApi


class TestIncludeExcludesApi(unittest.TestCase):
    """IncludeExcludesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = IncludeExcludesApi()

    def tearDown(self) -> None:
        pass

    def test_list_include_excludes(self) -> None:
        """Test case for list_include_excludes

        List
        """
        pass

    def test_update_include_excludes(self) -> None:
        """Test case for update_include_excludes

        Update
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Analysis

    Analyse content using Linked Data and Knowledge Graphs.

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wordlift_client.api.content_generation_records_api import ContentGenerationRecordsApi


class TestContentGenerationRecordsApi(unittest.TestCase):
    """ContentGenerationRecordsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ContentGenerationRecordsApi()

    def tearDown(self) -> None:
        pass

    def test_get_record(self) -> None:
        """Test case for get_record

        Get
        """
        pass

    def test_list_records(self) -> None:
        """Test case for list_records

        List
        """
        pass

    def test_list_records_as_events(self) -> None:
        """Test case for list_records_as_events

        List as Events
        """
        pass

    def test_update_record(self) -> None:
        """Test case for update_record

        Update
        """
        pass

    def test_update_records(self) -> None:
        """Test case for update_records

        Update
        """
        pass

    def test_update_records_collection(self) -> None:
        """Test case for update_records_collection

        Update
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Analysis

    Analyse content using Linked Data and Knowledge Graphs.

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wordlift_client.models.page_rule import PageRule

class TestPageRule(unittest.TestCase):
    """PageRule unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PageRule:
        """Test PageRule
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PageRule`
        """
        model = PageRule()
        if include_optional:
            return PageRule(
                first = '',
                items = [
                    wordlift_client.models.rule.Rule(
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        description = '', 
                        fixes = [
                            wordlift_client.models.validation_fix.ValidationFix(
                                type = 'FIND_AND_REPLACE', 
                                what = '', 
                                with = '', )
                            ], 
                        id = 56, 
                        is_enabled = True, 
                        level = 'RECOMMENDED', 
                        modified_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        name = '', 
                        project_id = 56, 
                        project_type = 'SMART_CONTENT', 
                        scope = 'USER', 
                        type = '', 
                        what_operand_lhs = 'EVERYWHERE', 
                        what_operand_rhs = '', 
                        what_operator = 'CONTAINS', 
                        when_operand_lhs = '', 
                        when_operand_rhs = '', 
                        when_operator = 'ALWAYS', )
                    ],
                last = '',
                next = '',
                prev = '',
                var_self = ''
            )
        else:
            return PageRule(
                first = '',
                items = [
                    wordlift_client.models.rule.Rule(
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        description = '', 
                        fixes = [
                            wordlift_client.models.validation_fix.ValidationFix(
                                type = 'FIND_AND_REPLACE', 
                                what = '', 
                                with = '', )
                            ], 
                        id = 56, 
                        is_enabled = True, 
                        level = 'RECOMMENDED', 
                        modified_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        name = '', 
                        project_id = 56, 
                        project_type = 'SMART_CONTENT', 
                        scope = 'USER', 
                        type = '', 
                        what_operand_lhs = 'EVERYWHERE', 
                        what_operand_rhs = '', 
                        what_operator = 'CONTAINS', 
                        when_operand_lhs = '', 
                        when_operand_rhs = '', 
                        when_operator = 'ALWAYS', )
                    ],
                last = '',
                next = '',
                prev = '',
                var_self = '',
        )
        """

    def testPageRule(self):
        """Test PageRule"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Analysis

    Analyse content using Linked Data and Knowledge Graphs.

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wordlift_client.models.question_and_answer_request import QuestionAndAnswerRequest

class TestQuestionAndAnswerRequest(unittest.TestCase):
    """QuestionAndAnswerRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> QuestionAndAnswerRequest:
        """Test QuestionAndAnswerRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `QuestionAndAnswerRequest`
        """
        model = QuestionAndAnswerRequest()
        if include_optional:
            return QuestionAndAnswerRequest(
                smart_content_id = 56,
                webpage_properties = wordlift_client.models.webpage_properties.WebpageProperties(
                    entities = [
                        ''
                        ], 
                    iri = '', 
                    query = '', 
                    url = '', )
            )
        else:
            return QuestionAndAnswerRequest(
        )
        """

    def testQuestionAndAnswerRequest(self):
        """Test QuestionAndAnswerRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Analysis

    Analyse content using Linked Data and Knowledge Graphs.

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wordlift_client.models.request import Request

class TestRequest(unittest.TestCase):
    """Request unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Request:
        """Test Request
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Request`
        """
        model = Request()
        if include_optional:
            return Request(
                html = wordlift_client.models.html.Html(
                    fragment = '', 
                    page = '', ),
                url = '',
                url_client = 'CHROME',
                language = '01',
                text = '',
                exclude = [
                    ''
                    ],
                scope = '',
                matches = 56,
                links = ''
            )
        else:
            return Request(
                language = '01',
                scope = '',
        )
        """

    def testRequest(self):
        """Test Request"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Embeddings API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from wordlift_client.models.embedding_request import EmbeddingRequest
from typing import Optional, Set
from typing_extensions import Self

class SitemapImportRequest(BaseModel):
    """
    The Sitemap Import request
    """ # noqa: E501
    embedding: Optional[EmbeddingRequest] = None
    id_generator: Optional[StrictStr] = Field(default='default', description="The entity id generator, by default uses the web page path.")
    output_types: Optional[List[StrictStr]] = Field(default=None, description="The type of the generated entities, by default `http://schema.org/WebPage`.")
    overwrite: Optional[StrictBool] = Field(default=False, description="Whether to overwrite existing entities.")
    sitemap_url: Optional[StrictStr] = Field(default=None, description="The sitemap URL")
    sitemap_url_regex: Optional[StrictStr] = Field(default=None, description="A regex filter to apply to discovered URLs, it only applies to URLs in sitemaps.")
    urls: Optional[List[StrictStr]] = Field(default=None, description="The URLs")
    __properties: ClassVar[List[str]] = ["embedding", "id_generator", "output_types", "overwrite", "sitemap_url", "sitemap_url_regex", "urls"]

    @field_validator('id_generator')
    def id_generator_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['default', 'headline-with-url-hash']):
            raise ValueError("must be one of enum values ('default', 'headline-with-url-hash')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of SitemapImportRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of embedding
        if self.embedding:
            _dict['embedding'] = self.embedding.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of SitemapImportRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "embedding": EmbeddingRequest.from_dict(obj["embedding"]) if obj.get("embedding") is not None else None,
            "id_generator": obj.get("id_generator") if obj.get("id_generator") is not None else 'default',
            "output_types": obj.get("output_types"),
            "overwrite": obj.get("overwrite") if obj.get("overwrite") is not None else False,
            "sitemap_url": obj.get("sitemap_url"),
            "sitemap_url_regex": obj.get("sitemap_url_regex"),
            "urls": obj.get("urls")
        })
        return _obj





# coding: utf-8

"""
    Analysis

    Analyse content using Linked Data and Knowledge Graphs.

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wordlift_client.models.page_merchant_view import PageMerchantView

class TestPageMerchantView(unittest.TestCase):
    """PageMerchantView unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PageMerchantView:
        """Test PageMerchantView
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PageMerchantView`
        """
        model = PageMerchantView()
        if include_optional:
            return PageMerchantView(
                first = '',
                items = [
                    wordlift_client.models.merchant_view.MerchantView(
                        access_token = '', 
                        account_id = 56, 
                        automatic_synchronization = True, 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        dataset_domain = '', 
                        dataset_name = '', 
                        deleted = True, 
                        deleted_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        google_merchant_id = 56, 
                        id = 56, 
                        ignore_brand = True, 
                        ignore_image = True, 
                        modified_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        publisher_name = '', 
                        refresh_token = '', 
                        sid = '', 
                        sync_has_errors = True, 
                        sync_id = 56, 
                        sync_products_created = 56, 
                        sync_products_deleted = 56, 
                        sync_products_errored = 56, 
                        sync_products_skipped = 56, 
                        sync_products_total = 56, 
                        sync_products_updated = 56, 
                        sync_started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        sync_stopped_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        url = '', 
                        writer_service = '', )
                    ],
                last = '',
                next = '',
                prev = '',
                var_self = ''
            )
        else:
            return PageMerchantView(
                first = '',
                items = [
                    wordlift_client.models.merchant_view.MerchantView(
                        access_token = '', 
                        account_id = 56, 
                        automatic_synchronization = True, 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        dataset_domain = '', 
                        dataset_name = '', 
                        deleted = True, 
                        deleted_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        google_merchant_id = 56, 
                        id = 56, 
                        ignore_brand = True, 
                        ignore_image = True, 
                        modified_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        publisher_name = '', 
                        refresh_token = '', 
                        sid = '', 
                        sync_has_errors = True, 
                        sync_id = 56, 
                        sync_products_created = 56, 
                        sync_products_deleted = 56, 
                        sync_products_errored = 56, 
                        sync_products_skipped = 56, 
                        sync_products_total = 56, 
                        sync_products_updated = 56, 
                        sync_started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        sync_stopped_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        url = '', 
                        writer_service = '', )
                    ],
                last = '',
                next = '',
                prev = '',
                var_self = '',
        )
        """

    def testPageMerchantView(self):
        """Test PageMerchantView"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Analysis

    Analyse content using Linked Data and Knowledge Graphs.

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wordlift_client.models.analyses_request import AnalysesRequest

class TestAnalysesRequest(unittest.TestCase):
    """AnalysesRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AnalysesRequest:
        """Test AnalysesRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AnalysesRequest`
        """
        model = AnalysesRequest()
        if include_optional:
            return AnalysesRequest(
                text = '',
                url = '',
                query = '',
                html = '',
                language_code = 'en',
                query_location_name = 'United States',
                query_search_engine = 'google.co.uk',
                linked_data = True,
                local_data = True,
                network_data = True
            )
        else:
            return AnalysesRequest(
        )
        """

    def testAnalysesRequest(self):
        """Test AnalysesRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
